@@ -5,7 +5,8 @@ using namespace proxyc;
 using namespace arma;
 
 rowvec stddev(const sp_mat& mt, const int norm_type) {
-    rowvec v(mt.n_cols);
+    rowvec v(mt.n_cols, fill::zeros);
+    if (mt.is_empty()) return(v);
     for (uword i = 0; i < mt.n_cols; i++) {
         v[i] = stddev(colvec(mt.col(i)), norm_type);
     }
@@ -13,7 +14,8 @@ rowvec stddev(const sp_mat& mt, const int norm_type) {
 }
 
 rowvec mean(const sp_mat& mt) {
-    rowvec v(mt.n_cols);
+    rowvec v(mt.n_cols, fill::zeros);
+    if (mt.is_empty()) return(v);
     for (uword i = 0; i < mt.n_cols; i++) {
         v[i] = mean(colvec(mt.col(i)));
     }
@@ -79,7 +81,8 @@ S4 cpp_linear(arma::sp_mat& mt1,
               arma::sp_mat& mt2,
               const int method,
               unsigned int rank,
-              double limit = -1.0) {
+              double limit = -1.0,
+              bool symm = false) {
 
     if (mt1.n_rows != mt2.n_rows)
         throw std::range_error("Invalid matrix objects");
@@ -87,7 +90,7 @@ S4 cpp_linear(arma::sp_mat& mt1,
     uword ncol1 = mt1.n_cols;
     uword ncol2 = mt2.n_cols;
     if (rank < 1) rank = 1;
-    bool symm = rank == ncol1 && rank == ncol2;
+    symm = symm && rank == ncol2;
 
     //dev::Timer timer;
     //dev::start_timer("Compute magnitude", timer);
@@ -126,7 +129,7 @@ S4 cpp_linear(arma::sp_mat& mt1,
 /***R
 mt <- Matrix::rsparsematrix(100, 100, 0.01)
 system.time(
-    out <- cpp_linear(mt, mt, 1, 100)
+    out <- cpp_linear(mt, mt, 1, 100, symm = TRUE)
 )
 */
 
